This is a python package based on the source code for ["An MCMC Based Course to Teaching Assistant Allocation", S. Kumar, S. Moothedath, P. Chaporkar, M. Belur, Proceedings of the Fifth International Conference on Network, Communication and Computing (2016). ACM.](https://doi.org/10.1145/3033288.3033297)
    
    PS: The code is currently not optimized for performance and readability!

#### Requirements:
- pandas
- numpy

#### Try it out!
Install the mcmcAllotter package via pip with the following command:
```
pip install mcmcAllotter
```

#### Usage:
```
python main.py
```

**Note**: The packaging of this code is still underway. Although it is okay to try it, the work on performance, readability and API design is still ongoing.

#### Feedback
Please send your feedback to saurabhkm[AT]hotmail.com or create an issue.